)]}'
{"mistral/workflow/data_flow.py":[{"author":{"_account_id":8731,"name":"Renat Akhmerov","email":"renat.akhmerov@gmail.com","username":"rakhmerov"},"change_message_id":"4fdb4058d9a06f79a1571b21140f57cd5efc02a9","unresolved":false,"context_lines":[{"line_number":243,"context_line":"    # dictionaries with many entries it significantly increases memory"},{"line_number":244,"context_line":"    # footprint and reduces performance."},{"line_number":245,"context_line":"    in_context \u003d ("},{"line_number":246,"context_line":"        dict(task_ex.in_context)"},{"line_number":247,"context_line":"        if task_ex.in_context is not None else {}"},{"line_number":248,"context_line":"    )"},{"line_number":249,"context_line":""}],"source_content_type":"text/x-python","patch_set":5,"id":"9f6a8fd7_92b78987","line":246,"range":{"start_line":246,"start_character":8,"end_line":246,"end_character":32},"updated":"2018-04-18 05:45:57.000000000","message":"Just a note: this optimization has a huge influence on performance in case of large dictionaries. I experimented with context consisting of 40000 entries and before this change the operation of evaluating the final workflow context was taking 45 sec on my machine, now it takes ~10 sec and 50% less RAM.","commit_id":"4936d778e5ad1eebfd54c86f9daa249fb2ee8ab5"}]}
